require 'uu/os/cmd/command_client'
require 'uu/os/security/session'
module UU
  # CloudRuntime module.
  module CloudRuntime
    # Created to keep CloudRuntime classes dry.
    # @private
    class RuntimeBaseClass


      # This must be overridden in any children class.
      # @private
      PATH = ''

      # Default URLs where common commands are running.
      # @private
      DEFAULT_COMMON_BASE_URL = /https:\/\/(api|cmd)\.plus4u\.net/

      # @private
      DEFAULT_C3_BASE_URL = 'https://sys.plus4u.net'

      private

      # @private
      def self._init_command_client(path)
        # Try to auto-configure client base URL.
        ext_config = UU::OS::CMD::CommandClient.const_get(:EXTERNAL_CONFIGURATION)
        base_url = ext_config.get(:base_url, path)
        if base_url.nil? || base_url =~ DEFAULT_COMMON_BASE_URL
          UU::OS::CMD::CommandClient.load_configuration({'uu.cloud.runtime.base_url' => DEFAULT_C3_BASE_URL})
        end
        # Command is not yet invoked through uuGateway, therefore do not append routing data.
        UU::OS::CMD::CommandClient.load_configuration({'uu.cloud.runtime.append_routing_data' => 'false'})
      end

    end
  end
end
